@@ -1,9 +1,8 @@
-package Pcore::Ext v0.30.0;
+package Pcore::Ext v0.30.1;
 
 use Pcore -dist, -class;
 use Pcore::Ext::App;
 use Pcore::Util::Scalar qw[is_ref];
-use Package::Stash::XS qw[];
 
 has app => ( required => 1 );    # InstanceOf['Pcore::App']
 
@@ -59,23 +58,9 @@ sub rebuild_all ($self) {
     return;
 }
 
-sub clear_package_symbols ( $self, $package ) {
-    my $stash = Package::Stash::XS->new( P->class->module_to_package($package) );
-
-    for my $sym ( $stash->list_all_symbols ) {
-        next if substr( $sym, -1, 1 ) eq ':';
-
-        $stash->remove_glob($sym);
-    }
-
-    return;
-}
-
 sub clear_cache ($self) {
     for my $module ( keys $Pcore::Ext::App::MODULES->%* ) {
-        delete $INC{$module};
-
-        $self->clear_package_symbols($module);
+        P->class->unload($module);
     }
 
     undef $Pcore::Ext::App::FRAMEWORK if !$self->{app}->{devel};
@@ -113,7 +98,7 @@ sub _init_reload ($self) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 49                   | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
+## |    3 | 48                   | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
